@@ -1,7 +1,6 @@
-//                                  -*- C++ -*-
 /*
 
-Copyright (C) 1992, 1993, 1994, 1995 John W. Eaton
+Copyright (C) 1996 John W. Eaton
 
 This file is part of Octave.
 
@@ -17,45 +16,45 @@ for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #if !defined (octave_ComplexColumnVector_h)
 #define octave_ComplexColumnVector_h 1
 
-#include "Array.h"
+#if defined (__GNUG__)
+#pragma interface
+#endif
+
+#include "MArray.h"
 
 #include "mx-defs.h"
 
-extern "C++" {
-
-class ComplexColumnVector : public Array<Complex>
+class ComplexColumnVector : public MArray<Complex>
 {
 friend class ComplexMatrix;
 friend class ComplexRowVector;
 
 public:
 
-  ComplexColumnVector (void) : Array<Complex> () { }
-  ComplexColumnVector (int n) : Array<Complex> (n) { }
-  ComplexColumnVector (int n, const Complex& val) : Array<Complex> (n, val) { }
+  ComplexColumnVector (void) : MArray<Complex> () { }
+  ComplexColumnVector (int n) : MArray<Complex> (n) { }
+  ComplexColumnVector (int n, const Complex& val) : MArray<Complex> (n, val) { }
   ComplexColumnVector (const ColumnVector& a);
-  ComplexColumnVector (const Array<Complex>& a) : Array<Complex> (a) { }
-  ComplexColumnVector (const ComplexColumnVector& a) : Array<Complex> (a) { }
+  ComplexColumnVector (const MArray<Complex>& a) : MArray<Complex> (a) { }
+  ComplexColumnVector (const ComplexColumnVector& a) : MArray<Complex> (a) { }
 
   ComplexColumnVector& operator = (const ComplexColumnVector& a)
     {
-      Array<Complex>::operator = (a);
+      MArray<Complex>::operator = (a);
       return *this;
     }
 
-//  operator Array<Complex>& () const { return *this; }
+  bool operator == (const ComplexColumnVector& a) const;
+  bool operator != (const ComplexColumnVector& a) const;
 
-  int operator == (const ComplexColumnVector& a) const;
-  int operator != (const ComplexColumnVector& a) const;
-
-// destructive insert/delete/reorder operations
+  // destructive insert/delete/reorder operations
 
   ComplexColumnVector& insert (const ColumnVector& a, int r);
   ComplexColumnVector& insert (const ComplexColumnVector& a, int r);
@@ -73,11 +72,11 @@ public:
 
   friend ComplexColumnVector conj (const ComplexColumnVector& a);
 
-// resize is the destructive equivalent for this one
+  // resize is the destructive equivalent for this one
 
   ComplexColumnVector extract (int r1, int r2) const;
 
-// column vector by column vector -> column vector operations
+  // column vector by column vector -> column vector operations
 
   ComplexColumnVector& operator += (const ColumnVector& a);
   ComplexColumnVector& operator -= (const ColumnVector& a);
@@ -85,7 +84,7 @@ public:
   ComplexColumnVector& operator += (const ComplexColumnVector& a);
   ComplexColumnVector& operator -= (const ComplexColumnVector& a);
 
-// column vector by scalar -> column vector operations
+  // column vector by scalar -> column vector operations
 
   friend ComplexColumnVector operator + (const ComplexColumnVector& a,
 					 double s);
@@ -105,7 +104,7 @@ public:
   friend ComplexColumnVector operator / (const ColumnVector& a,
 					 const Complex& s);
 
-// scalar by column vector -> column vector operations
+  // scalar by column vector -> column vector operations
 
   friend ComplexColumnVector operator + (double s,
 					 const ComplexColumnVector& a); 
@@ -125,7 +124,7 @@ public:
   friend ComplexColumnVector operator / (const Complex& s,
 					 const ColumnVector& a);
 
-// matrix by column vector -> column vector operations
+  // matrix by column vector -> column vector operations
 
   friend ComplexColumnVector operator * (const ComplexMatrix& a,
 					 const ColumnVector& b);
@@ -133,7 +132,7 @@ public:
   friend ComplexColumnVector operator * (const ComplexMatrix& a,
 					 const ComplexColumnVector& b);
 
-// column vector by column vector -> column vector operations
+  // column vector by column vector -> column vector operations
 
   friend ComplexColumnVector operator + (const ComplexColumnVector& a,
 					 const ColumnVector& b);
@@ -155,12 +154,12 @@ public:
   friend ComplexColumnVector quotient (const ColumnVector& a,
 				       const ComplexColumnVector& b); 
 
-// matrix by column vector -> column vector operations
+  // matrix by column vector -> column vector operations
 
   friend ComplexColumnVector operator * (const Matrix& a,
 					 const ComplexColumnVector& b);
 
-// diagonal matrix by column vector -> column vector operations
+  // diagonal matrix by column vector -> column vector operations
 
   friend ComplexColumnVector operator * (const DiagMatrix& a,
 					 const ComplexColumnVector& b);
@@ -171,39 +170,30 @@ public:
   friend ComplexColumnVector operator * (const ComplexDiagMatrix& a,
 					 const ComplexColumnVector& b);
 
-// other operations
+  // other operations
 
-  friend ComplexColumnVector map (c_c_Mapper f, const ComplexColumnVector& a);
-  void map (c_c_Mapper f);
+  ComplexColumnVector map (c_c_Mapper f) const;
+  ColumnVector map (d_c_Mapper f) const;
+
+  ComplexColumnVector& apply (c_c_Mapper f);
 
   Complex min (void) const;
   Complex max (void) const;
 
-// i/o
+  // i/o
 
   friend ostream& operator << (ostream& os, const ComplexColumnVector& a);
   friend istream& operator >> (istream& is, ComplexColumnVector& a);
 
-#define KLUDGE_VECTORS
-#define TYPE Complex
-#define KL_VEC_TYPE ComplexColumnVector
-#include "mx-kludge.h"
-#undef KLUDGE_VECTORS
-#undef TYPE
-#undef KL_VEC_TYPE
-
 private:
 
-  ComplexColumnVector (Complex *d, int l) : Array<Complex> (d, l) { }
+  ComplexColumnVector (Complex *d, int l) : MArray<Complex> (d, l) { }
 };
 
-} // extern "C++"
-
 #endif
 
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
-;;; page-delimiter: "^/\\*" ***
 ;;; End: ***
 */
