@@ -3760,10 +3760,12 @@ operator >> (istream& is, ComplexMatrix& a)
 	    if (is)
 	      a.elem (i, j) = tmp;
 	    else
-	      break;
+	      goto done;
 	  }
     }
 
+done:
+
   return is;
 }
 
