@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -80,6 +80,9 @@ private:
 
   int init (const Matrix& a);
   int init (const ComplexMatrix& a);
+
+  int symmetric_init (const Matrix& a);
+  int hermitian_init (const ComplexMatrix& a);
 };
 
 #endif
