@@ -1,7 +1,6 @@
-//                                  -*- C++ -*-
 /*
 
-Copyright (C) 1992, 1993, 1994, 1995 John W. Eaton
+Copyright (C) 1996 John W. Eaton
 
 This file is part of Octave.
 
@@ -17,64 +16,60 @@ for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #if !defined (octave_QRP_h)
 #define octave_QRP_h 1
 
+#if defined (__GNUG__)
+#pragma interface
+#endif
+
 class ostream;
 
 #include "dbleQR.h"
 
-extern "C++" {
-
-class QRP : public QR
+class
+QRP : public QR
 {
 public:
 
-  QRP (void) {}
+  QRP (void) : QR (), p () { }
 
-  QRP (const Matrix& A, QR::type qr_type = QR::std);
+  QRP (const Matrix&, QR::type = QR::std);
 
-  QRP (const QRP& a);
+  QRP (const QRP& a) : QR (a), p (a.p) { }
 
-  QRP& operator = (const QRP& a);
+  QRP& operator = (const QRP& a)
+    {
+      if (this != &a)
+	{
+	  QR::operator = (a);
+	  p = a.p;
+	}
 
-  Matrix P (void) const;
+      return *this;
+    }
 
-  friend ostream&  operator << (ostream& os, const QRP& a);
+  ~QRP (void) { }
 
-private:
+  void init (const Matrix&, QR::type = QR::std);
+
+  Matrix P (void) const { return p; }
+
+  friend ostream&  operator << (ostream&, const QRP&);
+
+protected:
 
   Matrix p;
 };
 
-inline QRP::QRP (const QRP& a) : QR (a)
-{
-  p = a.p;
-}
-
-inline QRP& QRP::operator = (const QRP& a)
-{
-  QR::operator = (a);
-  p = a.p;
-  return *this;
-}
-
-inline Matrix QRP::P (void) const
-{
-  return p;
-}
-
-} // extern "C++"
-
 #endif
 
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
-;;; page-delimiter: "^/\\*" ***
 ;;; End: ***
 */
