@@ -31,10 +31,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <floatingpoint.h>
 #endif
 
-#if defined (HAVE_IEEEFP_H)
-#include <ieeefp.h>
-#endif
-
 #if defined (HAVE_NAN_H)
 #if defined (SCO)
 #define _IEEE 1
@@ -45,6 +41,14 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 #endif
 
+#if defined (HAVE_INFINITY)
+extern "C" double infinity ();
+#endif
+
+#if defined (HAVE_QUIET_NAN)
+extern "C" double quiet_nan (long);
+#endif
+
 #include "lo-ieee.h"
 
 // Octave's idea of infinity.
@@ -64,9 +68,13 @@ octave_ieee_init (void)
 #if defined (SCO)
   double tmp = 1.0;
   octave_Inf = 1.0 / (tmp - tmp);
-#elif defined (__alpha__) && ! defined (linux)
+#elif defined (__alpha__)
   extern unsigned int DINFINITY[2];
   octave_Inf =  (*((double *) (DINFINITY)));
+#elif defined (HAVE_INFINITY)
+  octave_Inf = infinity ();
+#elif defined (linux)
+  octave_Inf = HUGE_VAL;
 #else
   double tmp = 1e+10;
   octave_Inf = tmp;
@@ -83,9 +91,13 @@ octave_ieee_init (void)
 
 #if defined (HAVE_ISNAN)
 
-#if defined (__alpha__) && ! defined (linux)
+#if defined (linux)
+  octave_NaN = NAN;
+#elif defined (__alpha__)
   extern unsigned int DQNAN[2];
   octave_NaN = (*((double *) (DQNAN)));
+#elif defined (HAVE_QUIET_NAN)
+  octave_NaN = quiet_nan (0L);
 #else
   octave_NaN = octave_Inf / octave_Inf;
 #endif
