@@ -171,7 +171,11 @@ xfinite (double x)
 double
 xgamma (double x)
 {
-  return F77_FCN (dgamma, DGAMMA) (x);
+  double result;
+
+  F77_XFCN (xdgamma, XDGAMMA, (x, result));
+
+  return result;
 }
 
 double
@@ -192,7 +196,7 @@ xlgamma (double x)
   double result;
   double sgngam;
 
-  F77_FCN (dlgams, DLGAMS) (x, result, sgngam);
+  F77_XFCN (dlgams, DLGAMS, (x, result, sgngam));
 
   return result;
 }
@@ -231,8 +235,8 @@ Complex
 acos (const Complex& x)
 {
   static Complex i (0, 1);
-  Complex retval = -i * log (x + sqrt (x*x - 1.0));
-  return retval;
+
+  return (real (x) * imag (x) < 0.0) ? i * acosh (x) : -i * acosh (x);
 }
 
 Complex
