@@ -32,9 +32,13 @@ extern double imag (double x);
 extern double real (double x);
 extern double round (double x);
 extern double signum (double x);
+extern double xerf (double x);
+extern double xerfc (double x);
 extern double xisnan (double x);
 extern double xfinite (double x);
+extern double xgamma (double x);
 extern double xisinf (double x);
+extern double xlgamma (double x);
 
 extern double xisnan (const Complex& x);
 extern double xfinite (const Complex& x);
