@@ -1,7 +1,6 @@
-// SLStack-sym.cc                                          -*- C++ -*-
 /*
 
-Copyright (C) 1993, 1994, 1995 John W. Eaton
+Copyright (C) 1996 John W. Eaton
 
 This file is part of Octave.
 
@@ -17,12 +16,22 @@ for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 // Instantiate Stacks of symbol_def* values.
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "SLList.h"
+#include "SLList.cc"
+
+#include "Stack.h"
+#include "Stack.cc"
+
 #include "SLStack.h"
 #include "SLStack.cc"
 
@@ -30,17 +39,20 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 extern template class SLNode<unsigned>;
 extern template class SLList<unsigned>;
+
 extern template class Stack<unsigned>;
+
 extern template class SLStack<unsigned>;
 
 template class SLNode<symbol_def *>;
 template class SLList<symbol_def *>;
+
 template class Stack<symbol_def *>;
+
 template class SLStack<symbol_def *>;
 
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
-;;; page-delimiter: "^/\\*" ***
 ;;; End: ***
 */
