@@ -463,13 +463,33 @@ make_diag (const octave_value& a, const octave_value& b)
     }
 
   int k = NINT (tmp);
+  int n = ABS (k) + 1;
 
   if (a.is_real_type ())
     {
-      Matrix m = a.matrix_value ();
-
-      if (! error_state)
+      if (a.is_scalar_type ())
 	{
+	  double d = a.double_value ();
+
+	  if (k == 0)
+	    retval = d;
+	  else if (k > 0)
+	    {
+	      Matrix m (n, n, 0.0);
+	      m (0, k) = d;
+	      retval = m;
+	    }
+	  else if (k < 0)
+	    {
+	      Matrix m (n, n, 0.0);
+	      m (-k, 0) = d;
+	      retval = m;
+	    }
+	}
+      else if (a.is_matrix_type ())
+	{
+	  Matrix m = a.matrix_value ();
+
 	  int nr = m.rows ();
 	  int nc = m.columns ();
 
@@ -483,13 +503,34 @@ make_diag (const octave_value& a, const octave_value& b)
 	      retval = d;
 	    }
 	}
+      else
+	gripe_wrong_type_arg ("diag", a);
     }
   else if (a.is_complex_type ())
     {
-      ComplexMatrix cm = a.complex_matrix_value ();
-
-      if (! error_state)
+      if (a.is_scalar_type ())
 	{
+	  Complex c = a.complex_value ();
+
+	  if (k == 0)
+	    retval = c;
+	  else if (k > 0)
+	    {
+	      ComplexMatrix m (n, n, 0.0);
+	      m (0, k) = c;
+	      retval = m;
+	    }
+	  else if (k < 0)
+	    {
+	      ComplexMatrix m (n, n, 0.0);
+	      m (-k, 0) = c;
+	      retval = m;
+	    }
+	}
+      else if (a.is_matrix_type ())
+	{
+	  ComplexMatrix cm = a.complex_matrix_value ();
+
 	  int nr = cm.rows ();
 	  int nc = cm.columns ();
 
@@ -503,6 +544,8 @@ make_diag (const octave_value& a, const octave_value& b)
 	      retval = d;
 	    }
 	}
+      else
+	gripe_wrong_type_arg ("diag", a);
     }
   else
     gripe_wrong_type_arg ("diag", a);
@@ -654,13 +697,7 @@ DEFUN (sum, args, ,
 }
 
 DEFUN (sumsq, args, ,
-  "sumsq (X): sum of squares of elements.\n\
-\n\
-This function is equivalent to computing\n\
-\n\
-  sum (X .* conj (X))\n\
-\n\
-but it uses less memory and avoids calling conj if X is real.")
+  "sumsq (X): sum of squares of elements")
 {
   octave_value_list retval;
 
@@ -696,32 +733,6 @@ but it uses less memory and avoids calling conj if X is real.")
   return retval;
 }
 
-DEFUN (is_complex, args, ,
-  "is_complex (x): return nonzero if x is a complex numeric object")
-{
-  octave_value retval;
-
-  if (args.length () == 1)
-    retval = args(0).is_complex_type () ? 1.0 : 0.0;
-  else
-    print_usage ("is_complex");
-
-  return retval;
-}
-
-DEFUN (isnumeric, args, ,
-  "isnumeric (x): return nonzero if x is a numeric object")
-{
-  octave_value retval;
-
-  if (args.length () == 1)
-    retval = args(0).is_numeric_type () ? 1.0 : 0.0;
-  else
-    print_usage ("isnumeric");
-
-  return retval;
-}
-
 DEFUN (is_struct, args, ,
   "is_struct (x): return nonzero if x is a structure")
 {
@@ -853,8 +864,8 @@ static void
 get_dimensions (const octave_value& a, const octave_value& b,
 		const char *warn_for, int& nr, int& nc)
 {
-  nr = (a.is_empty ()) ? 0 : NINT (a.double_value ());
-  nc = (b.is_empty ()) ? 0 : NINT (b.double_value ());
+  nr = NINT (a.double_value ());
+  nc = NINT (b.double_value ());
 
   if (error_state)
     error ("%s: expecting two scalar arguments", warn_for);
@@ -1104,16 +1115,16 @@ treat_neg_dim_as_zero (void)
 void
 symbols_of_data (void)
 {
-  DEFCONST (I, Complex (0.0, 1.0),
+  DEFCONST (I, Complex (0.0, 1.0), 0, 0,
     "sqrt (-1)");
 
-  DEFCONST (Inf, octave_Inf,
+  DEFCONST (Inf, octave_Inf, 0, 0,
     "infinity");
 
-  DEFCONST (J, Complex (0.0, 1.0),
+  DEFCONST (J, Complex (0.0, 1.0), 0, 0,
     "sqrt (-1)");
 
-  DEFCONST (NaN, octave_NaN,
+  DEFCONST (NaN, octave_NaN, 0, 0,
     "not a number");
 
 #if defined (M_E)
@@ -1122,22 +1133,22 @@ symbols_of_data (void)
   double e_val = exp (1.0);
 #endif
 
-  DEFCONST (e, e_val,
+  DEFCONST (e, e_val, 0, 0,
     "exp (1)");
 
-  DEFCONST (eps, DBL_EPSILON,
+  DEFCONST (eps, DBL_EPSILON, 0, 0,
     "machine precision");
 
-  DEFCONST (i, Complex (0.0, 1.0),
+  DEFCONST (i, Complex (0.0, 1.0), 1, 0,
     "sqrt (-1)");
 
-  DEFCONST (inf, octave_Inf,
+  DEFCONST (inf, octave_Inf, 0, 0,
     "infinity");
 
-  DEFCONST (j, Complex (0.0, 1.0),
+  DEFCONST (j, Complex (0.0, 1.0), 1, 0,
     "sqrt (-1)");
 
-  DEFCONST (nan, octave_NaN,
+  DEFCONST (nan, octave_NaN, 0, 0,
     "not a number");
 
 #if defined (M_PI)
@@ -1146,13 +1157,13 @@ symbols_of_data (void)
   double pi_val = 4.0 * atan (1.0);
 #endif
 
-  DEFCONST (pi, pi_val,
+  DEFCONST (pi, pi_val, 0, 0,
     "ratio of the circumference of a circle to its diameter");
 
-  DEFCONST (realmax, DBL_MAX,
+  DEFCONST (realmax, DBL_MAX, 0, 0,
     "realmax (): return largest representable floating point number");
 
-  DEFCONST (realmin, DBL_MIN,
+  DEFCONST (realmin, DBL_MIN, 0, 0,
     "realmin (): return smallest representable floating point number");
 
   DEFVAR (treat_neg_dim_as_zero, 0.0, 0, treat_neg_dim_as_zero,
