@@ -69,11 +69,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define DEFINE_FUN_STRUCT(name, is_text_fcn, doc) \
   static builtin_function S ## name (#name, is_text_fcn, F ## name, doc)
 
-#define DEFINE_FUN_STRUCT_FUN(name) \
+#define DEFINE_FUN_STRUCT_FUN(name, is_text_fcn, doc) \
   builtin_function& \
   FS ## name (void) \
   { \
-    return S ## name; \
+    static builtin_function *retval = 0; \
+ \
+    if (! retval) \
+      retval = new builtin_function (#name, is_text_fcn, F ## name, doc); \
+ \
+    return *retval; \
   }
 
 #define DECLARE_FUN(name, args_name, nargout_name) \
