@@ -444,12 +444,13 @@ gnu_readline (const char *s, bool force_readline)
 
       char *buf = (char *) malloc (max_size);
       char *bufptr = buf;
+      int len = 0;
 
       do
 	{
 	  if (fgets (bufptr, grow_size, curr_stream))
 	    {
-	      int len = strlen (bufptr);
+	      len = strlen (bufptr);
 
 	      if (len == grow_size - 1)
 		{
@@ -475,7 +476,12 @@ gnu_readline (const char *s, bool force_readline)
 		retval = buf;
 	    }
 	  else
-	    break;
+	    {
+	      if (len == 0)
+		free (buf);
+
+	      break;
+	    }
 	}
       while (! retval);
     }
@@ -607,7 +613,15 @@ octave_read (char *buf, unsigned max_size)
 	}
     }
   else if (chars_left == 0)
-    status = 0;
+    {
+      if (input_buf)
+	{
+	  free (input_buf);
+	  input_buf = 0;
+	}
+
+      status = 0;
+    }
   else    
     status = -1;
 
@@ -1017,7 +1031,7 @@ match_sans_spaces (const char *standard, const char *test)
 // If the user simply hits return, this will produce an empty matrix.
 
 static octave_value_list
-get_user_input (const octave_value_list& args, int debug = 0)
+get_user_input (const octave_value_list& args, bool debug = false)
 {
   octave_value retval;
 
@@ -1080,7 +1094,9 @@ get_user_input (const octave_value_list& args, int debug = 0)
       else
 	{
 	  int parse_status = 0;
+
 	  retval = eval_string (input_buf, 0, parse_status);
+
 	  if (retval.is_defined ())
 	    {
 	      if (debug)
@@ -1102,7 +1118,7 @@ get_user_input (const octave_value_list& args, int debug = 0)
 DEFUN (input, args, ,
   "input (PROMPT [, S])\n\
 \n\
-Prompt user for input.  If the second argument is present, return
+Prompt user for input.  If the second argument is present, return\n\
 value as a string.")
 {
   octave_value_list retval;
@@ -1127,7 +1143,7 @@ maybe help in debugging function files")
   int nargin = args.length ();
 
   if (nargin == 0 || nargin == 1)
-    retval = get_user_input (args, 1);
+    retval = get_user_input (args, true);
   else
     print_usage ("keyboard");
 
