@@ -13,17 +13,17 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public
 License along with the GNU C Library; see the file COPYING.  If
-not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-Cambridge, MA 02139, USA.  */
+not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+Boston, MA  02111-1307, USA.  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #ifndef HAVE_STRCASECMP
 
-#include <string.h>
 #include <ctype.h>
+#include <string.h>
 
 /* Compare S1 and S2, ignoring case, returning less than, equal to or
    greater than zero if S1 is lexiographically less than,
