@@ -146,7 +146,7 @@ DEFUN (exec, args, ,
 \n\
 Replace current process with a new process.\n\
 \n\
-If successful, exec does not return.  If exec does return, status will
+If successful, exec does not return.  If exec does return, status will\n\
 be nonzero, and MSG will contain a system-dependent error message.")
 {
   octave_value_list retval;
@@ -606,7 +606,7 @@ STATUS is nonzero and MSG contains a system-dependent error message.")
 DEFUN (stat, args, ,
   "[S, ERR, MSG] = stat (NAME)\n\
 \n\
-  Given the name of a file, return a structure S with the following
+  Given the name of a file, return a structure S with the following\n\
   elements:\n\
 \n\
     dev     : id of device containing a directory entry for this file\n\
@@ -614,7 +614,7 @@ DEFUN (stat, args, ,
     modestr : file mode, as a string of ten letters or dashes as in ls -l\n\
     nlink   : number of links\n\
     uid     : user id of file's owner\n\
-    gid     : group id of file's group \n\
+    gid     : group id of file's group\n\
     rdev    : id of device for block or character special files\n\
     size    : size in bytes\n\
     atime   : time of last access\n\
@@ -713,7 +713,7 @@ Wait for process PID to terminate\n\
   OPTIONS is:\n\
 \n\
      0 : wait until signal is received or a child process exits (this\n\
-         is the default if the OPTIONS argument is missing) \n\
+         is the default if the OPTIONS argument is missing)\n\
      1 : do not hang if status is not immediately available\n\
      2 : report the status of any child processes that are\n\
          stopped, and whose status has not yet been reported\n\
